# Badlon

## Installation 

Bablon can be installed with `pip`:

```bash
pip install badlon
```

Now you can run tool from any directory as `badlon`.

## Usage

Badlon includes multiple modules to process data. They can be listed with help command:

```bash
pip install badlon
```